aboutsummaryrefslogtreecommitdiffstats
path: root/config
diff options
context:
space:
mode:
authorJa.KooLit <jimmielovejay@gmail.com>2024-01-07 08:24:09 +0900
committerGitHub <noreply@github.com>2024-01-07 08:24:09 +0900
commit27557af9ad6f952690e2547c8feec51271d5423c (patch)
tree14dd700bce757341d3063307550504193c2f395b /config
parentffbb2da07e040fb75ad89bfaacf03c8d73b7d8c1 (diff)
parent876a392a16bbdea0b16eb28a21b00819d12b9f1a (diff)
Merge branch 'development' into main
Diffstat (limited to 'config')
-rwxr-xr-xconfig/hypr/scripts/DarkLight.sh8
-rw-r--r--config/hypr/v2.2.4 (renamed from config/hypr/v2.2.3)0
-rw-r--r--config/rofi/config-compact.rasi5
-rw-r--r--config/rofi/config-long.rasi5
-rw-r--r--config/rofi/config-rofi-Beats.rasi5
-rw-r--r--config/rofi/config-wallpaper.rasi79
-rw-r--r--config/rofi/config-waybar-layout.rasi4
-rw-r--r--config/rofi/config-waybar-style.rasi4
-rw-r--r--config/rofi/config-zsh-theme.rasi5
-rw-r--r--config/rofi/config.rasi6
-rw-r--r--config/rofi/resolution/1080p/config-compact.rasi5
-rw-r--r--config/rofi/resolution/1080p/config-long.rasi5
-rw-r--r--config/rofi/resolution/1080p/config-rofi-Beats.rasi5
-rw-r--r--config/rofi/resolution/1080p/config-wallpaper.rasi79
-rw-r--r--config/rofi/resolution/1080p/config-waybar-layout.rasi4
-rw-r--r--config/rofi/resolution/1080p/config-waybar-style.rasi4
-rw-r--r--config/rofi/resolution/1080p/config-zsh-theme.rasi5
-rw-r--r--config/rofi/resolution/1080p/config.rasi6
-rw-r--r--config/rofi/resolution/1440p/config-compact.rasi5
-rw-r--r--config/rofi/resolution/1440p/config-long.rasi6
-rw-r--r--config/rofi/resolution/1440p/config-rofi-Beats.rasi6
-rw-r--r--config/rofi/resolution/1440p/config-wallpaper.rasi1
-rw-r--r--config/rofi/resolution/1440p/config-waybar-layout.rasi4
-rw-r--r--config/rofi/resolution/1440p/config-waybar-style.rasi4
-rw-r--r--config/rofi/resolution/1440p/config-zsh-theme.rasi5
-rw-r--r--config/rofi/resolution/1440p/config.rasi7
-rw-r--r--config/swaync/style.css1
27 files changed, 131 insertions, 142 deletions
diff --git a/config/hypr/v2.2.3 b/config/hypr/v2.2.4
index 31b3414d..31b3414d 100644
--- a/config/hypr/v2.2.3
+++ b/config/hypr/v2.2.4
diff --git a/config/rofi/config-compact.rasi b/config/rofi/config-compact.rasi
index b5b45592..2d68a6d0 100644
--- a/config/rofi/config-compact.rasi
+++ b/config/rofi/config-compact.rasi
@@ -39,7 +39,7 @@ window {
enabled: true;
border-radius: 15px;
border-radius: 15px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -47,10 +47,9 @@ mainbox {
enabled: true;
orientation: horizontal;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "imagebox"];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/config-long.rasi b/config/rofi/config-long.rasi
index ca6edf1a..9813d7e6 100644
--- a/config/rofi/config-long.rasi
+++ b/config/rofi/config-long.rasi
@@ -39,7 +39,7 @@ window {
fullscreen: false;
enabled: true;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -47,10 +47,9 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "imagebox" ];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/config-rofi-Beats.rasi b/config/rofi/config-rofi-Beats.rasi
index 8619b670..e59ace13 100644
--- a/config/rofi/config-rofi-Beats.rasi
+++ b/config/rofi/config-rofi-Beats.rasi
@@ -40,7 +40,7 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -48,10 +48,9 @@ mainbox {
enabled: true;
orientation: horizontal;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "imagebox"];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/config-wallpaper.rasi b/config/rofi/config-wallpaper.rasi
index 5f1cb172..3df1f67b 100644
--- a/config/rofi/config-wallpaper.rasi
+++ b/config/rofi/config-wallpaper.rasi
@@ -3,18 +3,18 @@
/* ---- Configuration ---- */
configuration {
- modi: "drun,run,filebrowser";
- font: "Fira Code SemiBold 12";
- show-icons: true;
- display-drun: "";
- display-run: "";
- display-filebrowser: "";
- display-window: "";
- drun-display-format: "{name}";
- hover-select: true;
- me-select-entry: "MouseSecondary";
- me-accept-entry: "MousePrimary";
- window-format: "{w} · {c} · {t}";
+ modi: "drun,run,filebrowser";
+ font: "Fira Code SemiBold 12";
+ show-icons: true;
+ display-drun: "";
+ display-run: "";
+ display-filebrowser: "";
+ display-window: "";
+ drun-display-format: "{name}";
+ hover-select: true;
+ me-select-entry: "MouseSecondary";
+ me-accept-entry: "MousePrimary";
+ window-format: "{w} · {c} · {t}";
dpi: 1;
}
@@ -25,7 +25,7 @@ configuration {
/* ---- Window ---- */
window {
width: 700px;
- /*height: 450px;*/
+ /*height: 450px;*/
x-offset: 0px;
y-offset: 0px;
spacing: 0px;
@@ -40,7 +40,6 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: transparent;
background-image: url("~/.config/rofi/.current_wallpaper", height);
}
@@ -143,66 +142,64 @@ element normal.normal {
}
element normal.urgent {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element normal.active {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element selected.normal {
- background-color: @selected-normal-background;
- text-color: @foreground;
+ background-color: @selected-normal-background;
+ text-color: @foreground;
}
element selected.urgent {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element selected.active {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element alternate.normal {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element alternate.urgent {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element alternate.active {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element-icon {
- background-color: transparent;
- text-color: inherit;
- size: 130px;
- cursor: inherit;
+ background-color: transparent;
+ text-color: inherit;
+ size: 130px;
+ cursor: inherit;
}
element-text {
- font: "Fira Code SemiBold 8";
- background-color: transparent;
- text-color: inherit;
- cursor: inherit;
- vertical-align: 0.5;
- horizontal-align: 0.5;
+ font: "Fira Code SemiBold 8";
+ background-color: transparent;
+ text-color: inherit;
+ cursor: inherit;
}
/*****----- Message -----*****/
message {
background-color: @background;
- margin: 20px 0px 0px 0px;
+ margin: 20px 0px 0px 0px;
border-radius: 10px;
}
diff --git a/config/rofi/config-waybar-layout.rasi b/config/rofi/config-waybar-layout.rasi
index ff72895a..18f7b8f9 100644
--- a/config/rofi/config-waybar-layout.rasi
+++ b/config/rofi/config-waybar-layout.rasi
@@ -40,7 +40,7 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -48,7 +48,7 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "inputbar", "listbox"];
border-radius: 12px;
}
diff --git a/config/rofi/config-waybar-style.rasi b/config/rofi/config-waybar-style.rasi
index f0132ee4..b48ef8c7 100644
--- a/config/rofi/config-waybar-style.rasi
+++ b/config/rofi/config-waybar-style.rasi
@@ -40,7 +40,7 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -48,7 +48,7 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "inputbar", "listbox"];
border-radius: 12px;
}
diff --git a/config/rofi/config-zsh-theme.rasi b/config/rofi/config-zsh-theme.rasi
index d669ccfa..c6aff123 100644
--- a/config/rofi/config-zsh-theme.rasi
+++ b/config/rofi/config-zsh-theme.rasi
@@ -41,7 +41,7 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -49,10 +49,9 @@ mainbox {
enabled: true;
orientation: horizontal;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", width);
+ background-color: transparent;
children: [ "imagebox"];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/config.rasi b/config/rofi/config.rasi
index 50cd75be..d21800f6 100644
--- a/config/rofi/config.rasi
+++ b/config/rofi/config.rasi
@@ -39,7 +39,7 @@ window {
fullscreen: false;
enabled: true;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -47,7 +47,7 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", width);
+ background-color: transparent;
children: [ "inputbar", "imagebox" ];
border-radius: 12px;
}
@@ -118,7 +118,7 @@ mode-switcher{
}
button {
- padding: 0px 10px 0px 10px;
+ padding: 0px 12px 0px 8px;
border-radius: 12px;
background-color: @background;
text-color: inherit;
diff --git a/config/rofi/resolution/1080p/config-compact.rasi b/config/rofi/resolution/1080p/config-compact.rasi
index b5b45592..2d68a6d0 100644
--- a/config/rofi/resolution/1080p/config-compact.rasi
+++ b/config/rofi/resolution/1080p/config-compact.rasi
@@ -39,7 +39,7 @@ window {
enabled: true;
border-radius: 15px;
border-radius: 15px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -47,10 +47,9 @@ mainbox {
enabled: true;
orientation: horizontal;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "imagebox"];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/resolution/1080p/config-long.rasi b/config/rofi/resolution/1080p/config-long.rasi
index ca6edf1a..9813d7e6 100644
--- a/config/rofi/resolution/1080p/config-long.rasi
+++ b/config/rofi/resolution/1080p/config-long.rasi
@@ -39,7 +39,7 @@ window {
fullscreen: false;
enabled: true;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -47,10 +47,9 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "imagebox" ];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/resolution/1080p/config-rofi-Beats.rasi b/config/rofi/resolution/1080p/config-rofi-Beats.rasi
index 8619b670..e59ace13 100644
--- a/config/rofi/resolution/1080p/config-rofi-Beats.rasi
+++ b/config/rofi/resolution/1080p/config-rofi-Beats.rasi
@@ -40,7 +40,7 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -48,10 +48,9 @@ mainbox {
enabled: true;
orientation: horizontal;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "imagebox"];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/resolution/1080p/config-wallpaper.rasi b/config/rofi/resolution/1080p/config-wallpaper.rasi
index 5f1cb172..3df1f67b 100644
--- a/config/rofi/resolution/1080p/config-wallpaper.rasi
+++ b/config/rofi/resolution/1080p/config-wallpaper.rasi
@@ -3,18 +3,18 @@
/* ---- Configuration ---- */
configuration {
- modi: "drun,run,filebrowser";
- font: "Fira Code SemiBold 12";
- show-icons: true;
- display-drun: "";
- display-run: "";
- display-filebrowser: "";
- display-window: "";
- drun-display-format: "{name}";
- hover-select: true;
- me-select-entry: "MouseSecondary";
- me-accept-entry: "MousePrimary";
- window-format: "{w} · {c} · {t}";
+ modi: "drun,run,filebrowser";
+ font: "Fira Code SemiBold 12";
+ show-icons: true;
+ display-drun: "";
+ display-run: "";
+ display-filebrowser: "";
+ display-window: "";
+ drun-display-format: "{name}";
+ hover-select: true;
+ me-select-entry: "MouseSecondary";
+ me-accept-entry: "MousePrimary";
+ window-format: "{w} · {c} · {t}";
dpi: 1;
}
@@ -25,7 +25,7 @@ configuration {
/* ---- Window ---- */
window {
width: 700px;
- /*height: 450px;*/
+ /*height: 450px;*/
x-offset: 0px;
y-offset: 0px;
spacing: 0px;
@@ -40,7 +40,6 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: transparent;
background-image: url("~/.config/rofi/.current_wallpaper", height);
}
@@ -143,66 +142,64 @@ element normal.normal {
}
element normal.urgent {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element normal.active {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element selected.normal {
- background-color: @selected-normal-background;
- text-color: @foreground;
+ background-color: @selected-normal-background;
+ text-color: @foreground;
}
element selected.urgent {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element selected.active {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element alternate.normal {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element alternate.urgent {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element alternate.active {
- background-color: inherit;
- text-color: @foreground;
+ background-color: inherit;
+ text-color: @foreground;
}
element-icon {
- background-color: transparent;
- text-color: inherit;
- size: 130px;
- cursor: inherit;
+ background-color: transparent;
+ text-color: inherit;
+ size: 130px;
+ cursor: inherit;
}
element-text {
- font: "Fira Code SemiBold 8";
- background-color: transparent;
- text-color: inherit;
- cursor: inherit;
- vertical-align: 0.5;
- horizontal-align: 0.5;
+ font: "Fira Code SemiBold 8";
+ background-color: transparent;
+ text-color: inherit;
+ cursor: inherit;
}
/*****----- Message -----*****/
message {
background-color: @background;
- margin: 20px 0px 0px 0px;
+ margin: 20px 0px 0px 0px;
border-radius: 10px;
}
diff --git a/config/rofi/resolution/1080p/config-waybar-layout.rasi b/config/rofi/resolution/1080p/config-waybar-layout.rasi
index ff72895a..18f7b8f9 100644
--- a/config/rofi/resolution/1080p/config-waybar-layout.rasi
+++ b/config/rofi/resolution/1080p/config-waybar-layout.rasi
@@ -40,7 +40,7 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -48,7 +48,7 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "inputbar", "listbox"];
border-radius: 12px;
}
diff --git a/config/rofi/resolution/1080p/config-waybar-style.rasi b/config/rofi/resolution/1080p/config-waybar-style.rasi
index f0132ee4..b48ef8c7 100644
--- a/config/rofi/resolution/1080p/config-waybar-style.rasi
+++ b/config/rofi/resolution/1080p/config-waybar-style.rasi
@@ -40,7 +40,7 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -48,7 +48,7 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "inputbar", "listbox"];
border-radius: 12px;
}
diff --git a/config/rofi/resolution/1080p/config-zsh-theme.rasi b/config/rofi/resolution/1080p/config-zsh-theme.rasi
index d669ccfa..c6aff123 100644
--- a/config/rofi/resolution/1080p/config-zsh-theme.rasi
+++ b/config/rofi/resolution/1080p/config-zsh-theme.rasi
@@ -41,7 +41,7 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -49,10 +49,9 @@ mainbox {
enabled: true;
orientation: horizontal;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", width);
+ background-color: transparent;
children: [ "imagebox"];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/resolution/1080p/config.rasi b/config/rofi/resolution/1080p/config.rasi
index 50cd75be..d21800f6 100644
--- a/config/rofi/resolution/1080p/config.rasi
+++ b/config/rofi/resolution/1080p/config.rasi
@@ -39,7 +39,7 @@ window {
fullscreen: false;
enabled: true;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -47,7 +47,7 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", width);
+ background-color: transparent;
children: [ "inputbar", "imagebox" ];
border-radius: 12px;
}
@@ -118,7 +118,7 @@ mode-switcher{
}
button {
- padding: 0px 10px 0px 10px;
+ padding: 0px 12px 0px 8px;
border-radius: 12px;
background-color: @background;
text-color: inherit;
diff --git a/config/rofi/resolution/1440p/config-compact.rasi b/config/rofi/resolution/1440p/config-compact.rasi
index 029fdbdf..825fff62 100644
--- a/config/rofi/resolution/1440p/config-compact.rasi
+++ b/config/rofi/resolution/1440p/config-compact.rasi
@@ -39,7 +39,7 @@ window {
enabled: true;
border-radius: 15px;
border-radius: 15px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -47,10 +47,9 @@ mainbox {
enabled: true;
orientation: horizontal;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "imagebox"];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/resolution/1440p/config-long.rasi b/config/rofi/resolution/1440p/config-long.rasi
index d4c55ac7..f8d0b4bf 100644
--- a/config/rofi/resolution/1440p/config-long.rasi
+++ b/config/rofi/resolution/1440p/config-long.rasi
@@ -39,7 +39,8 @@ window {
fullscreen: false;
enabled: true;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
+
}
/* ---- Mainbox ---- */
@@ -47,10 +48,9 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "imagebox" ];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/resolution/1440p/config-rofi-Beats.rasi b/config/rofi/resolution/1440p/config-rofi-Beats.rasi
index 521875f2..141c9ed4 100644
--- a/config/rofi/resolution/1440p/config-rofi-Beats.rasi
+++ b/config/rofi/resolution/1440p/config-rofi-Beats.rasi
@@ -40,7 +40,8 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
+
}
/* ---- Mainbox ---- */
@@ -48,10 +49,9 @@ mainbox {
enabled: true;
orientation: horizontal;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "imagebox"];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/resolution/1440p/config-wallpaper.rasi b/config/rofi/resolution/1440p/config-wallpaper.rasi
index 0bc3b106..3f01dc0a 100644
--- a/config/rofi/resolution/1440p/config-wallpaper.rasi
+++ b/config/rofi/resolution/1440p/config-wallpaper.rasi
@@ -40,7 +40,6 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: transparent;
background-image: url("~/.config/rofi/.current_wallpaper", height);
}
diff --git a/config/rofi/resolution/1440p/config-waybar-layout.rasi b/config/rofi/resolution/1440p/config-waybar-layout.rasi
index b4484563..b829de39 100644
--- a/config/rofi/resolution/1440p/config-waybar-layout.rasi
+++ b/config/rofi/resolution/1440p/config-waybar-layout.rasi
@@ -40,7 +40,7 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -48,7 +48,7 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "inputbar", "listbox"];
border-radius: 12px;
}
diff --git a/config/rofi/resolution/1440p/config-waybar-style.rasi b/config/rofi/resolution/1440p/config-waybar-style.rasi
index 6700c1d6..de7e6933 100644
--- a/config/rofi/resolution/1440p/config-waybar-style.rasi
+++ b/config/rofi/resolution/1440p/config-waybar-style.rasi
@@ -40,7 +40,7 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", height);
}
/* ---- Mainbox ---- */
@@ -48,7 +48,7 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", height);
+ background-color: transparent;
children: [ "inputbar", "listbox"];
border-radius: 12px;
}
diff --git a/config/rofi/resolution/1440p/config-zsh-theme.rasi b/config/rofi/resolution/1440p/config-zsh-theme.rasi
index 7173c3ae..9ab3c0a6 100644
--- a/config/rofi/resolution/1440p/config-zsh-theme.rasi
+++ b/config/rofi/resolution/1440p/config-zsh-theme.rasi
@@ -41,7 +41,7 @@ window {
enabled: true;
border-radius: 12px;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", width);
}
/* ---- Mainbox ---- */
@@ -49,10 +49,9 @@ mainbox {
enabled: true;
orientation: horizontal;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", width);
+ background-color: transparent;
children: [ "imagebox"];
border-radius: 12px;
- background-color: @background;
}
/* ---- Imagebox ---- */
diff --git a/config/rofi/resolution/1440p/config.rasi b/config/rofi/resolution/1440p/config.rasi
index 250c46b4..83c481cf 100644
--- a/config/rofi/resolution/1440p/config.rasi
+++ b/config/rofi/resolution/1440p/config.rasi
@@ -39,7 +39,8 @@ window {
fullscreen: false;
enabled: true;
border-radius: 12px;
- background-color: @background-color;
+ background-image: url("~/.config/rofi/.current_wallpaper", width);
+
}
/* ---- Mainbox ---- */
@@ -47,7 +48,7 @@ mainbox {
enabled: true;
orientation: vertical;
padding: 8px;
- background-image: url("~/.config/rofi/.current_wallpaper", width);
+ background-color: transparent;
children: [ "inputbar", "imagebox" ];
border-radius: 12px;
}
@@ -118,7 +119,7 @@ mode-switcher{
}
button {
- padding: 0px 10px 0px 10px;
+ padding: 0px 12px 0px 8px;
border-radius: 12px;
background-color: @background;
text-color: inherit;
diff --git a/config/swaync/style.css b/config/swaync/style.css
index f0d41fb4..728e2157 100644
--- a/config/swaync/style.css
+++ b/config/swaync/style.css
@@ -162,6 +162,7 @@
.control-center {
background: @noti-bg;
border: 2px solid @noti-border-color;
+ color: @text-color;
border-radius: 10px;
}
send patches to the email below
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage
diff --git a/config/hypr/scripts/DarkLight.sh b/config/hypr/scripts/DarkLight.sh
index dab6e816..885c7c6a 100755
--- a/config/hypr/scripts/DarkLight.sh
+++ b/config/hypr/scripts/DarkLight.sh
@@ -147,8 +147,10 @@ set_custom_gtk_theme() {
echo "Selected GTK theme for $mode mode: $selected_theme"
gsettings set $theme_setting "$selected_theme"
# Flatpak GTK apps
if command -v flatpak &> /dev/null; then
+ flatpak --user override --filesystem=$HOME/.themes
+ sleep 0.5
flatpak --user override --env=GTK_THEME="$selected_theme"
fi
else
@@ -168,8 +170,10 @@ set_custom_gtk_theme() {
sed -i "s|^icon_theme=.*$|icon_theme=$selected_icon|" "$HOME/.config/qt5ct/qt5ct.conf"
sed -i "s|^icon_theme=.*$|icon_theme=$selected_icon|" "$HOME/.config/qt6ct/qt6ct.conf"
# Flatpak GTK apps
if command -v flatpak &> /dev/null; then
+ flatpak --user override --filesystem=$HOME/.icons
+ sleep 0.5
flatpak --user override --env=ICON_THEME="$selected_icon"
fi
else
@@ -147,8 +147,10 @@ set_custom_gtk_theme() {
echo "Selected GTK theme for $mode mode: $selected_theme"
gsettings set $theme_setting "$selected_theme"
- # Flatpak GTK apps
+ # Flatpak GTK apps (themes)
if command -v flatpak &> /dev/null; then
@@ -168,8 +170,10 @@ set_custom_gtk_theme() {
sed -i "s|^icon_theme=.*$|icon_theme=$selected_icon|" "$HOME/.config/qt5ct/qt5ct.conf"
sed -i "s|^icon_theme=.*$|icon_theme=$selected_icon|" "$HOME/.config/qt6ct/qt6ct.conf"
- # Flatpak GTK apps
+ # Flatpak GTK apps (icons)
if command -v flatpak &> /dev/null; then